@@ -52,13 +52,13 @@ create_us_map <- function(
 ) {
   # check for dplyr
   if (!requireNamespace("dplyr", quietly = TRUE)) {
-    stop("`dplyr` must be installed to use `dplyr`.
+    stop("`dplyr` must be installed to use `create_us_map()`.
          Use: install.packages(\"dplyr\") and try again.")
   }
 
   type <- match.arg(type)
 
-  # import map shape file
+  # import map file
   us <- sf::read_sf(input_file)
 
   # ea: US National Atlas Equal Area
@@ -229,27 +229,31 @@ compute_centroids <- function(polygons, iterations = 3, initial_width_step = 10)
 #' @rdname create_us_map
 #' @keywords internal
 alaska_bbox <- function() {
-  sf::st_bbox(
-    c(
-      xmin = -4377000,
-      xmax = -1519000,
-      ymin = 1466000,
-      ymax = 3914000
-    ),
-    crs = ea_crs()
+  sf::st_as_sfc(
+    sf::st_bbox(
+      c(
+        xmin = -4377000,
+        xmax = -1519000,
+        ymin = 1466000,
+        ymax = 3914000
+      ),
+      crs = ea_crs()
+    )
   )
 }
 
 #' @rdname create_us_map
 #' @keywords internal
 hawaii_bbox <- function() {
-  sf::st_bbox(
-    c(
-      xmin = -5750000,
-      xmax = -5450000,
-      ymin = -1050000,
-      ymax = -441000
-    ),
-    crs = ea_crs()
+  sf::st_as_sfc(
+    sf::st_bbox(
+      c(
+        xmin = -5750000,
+        xmax = -5450000,
+        ymin = -1050000,
+        ymax = -441000
+      ),
+      crs = ea_crs()
+    )
   )
 }
